Simple Rest Client
==================

|Github Actions Status| |Coverage Status| |Requirements Status|
|Code Climate|

----

Simple REST client for python 3.6+.


How to install
--------------

.. code:: shell

    pip install simple-rest-client


Documentation
--------------

Check out documentation at `Read the Docs`_ website.

.. _`Read the Docs`: https://python-simple-rest-client.readthedocs.io/en/latest/


Projects using
--------------

- `python-vindi`_
- `sentry-patrol`_

.. _`python-vindi`: https://github.com/allisson/python-vindi
.. _`sentry-patrol`: https://github.com/daneoshiga/sentry-patrol

.. |Github Actions Status| image:: https://github.com/allisson/python-simple-rest-client/workflows/main-workflow/badge.svg
   :target: https://github.com/allisson/python-simple-rest-client/actions
.. |Coverage Status| image:: https://codecov.io/gh/allisson/python-simple-rest-client/branch/master/graph/badge.svg
   :target: https://codecov.io/gh/allisson/python-simple-rest-client
.. |Requirements Status| image:: https://requires.io/github/allisson/python-simple-rest-client/requirements.svg?branch=master
   :target: https://requires.io/github/allisson/python-simple-rest-client/requirements/?branch=master
.. |Code Climate| image:: https://codeclimate.com/github/allisson/python-simple-rest-client/badges/gpa.svg
   :target: https://codeclimate.com/github/allisson/python-simple-rest-client
